
 /////////////////////////////////////////////////////////////////////////////
 // This source code is part of the graphical framework called “Knižnica
 // grafického robota”. (The name is Slovak like the vast majority of own
 // identifiers used in this project.) The name translated to English means
 // “The Graphical Robot Library.”
 // 
 // Copyright © 2010 – 2016 by Roman Horváth
 // 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
 // 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU General Public License for more details.
 // 
 // You should have received a copy of the GNU General Public License
 // along with this program (look for the file named license.txt). If not,
 // see <http://www.gnu.org/licenses/> or
 // <https://www.gnu.org/licenses/gpl-3.0.txt>.
 // 
 // In case of any questions or requests, please, contact the author
 // Roman Horváth by e-mail: roman.horvath@truni.sk
 // or horvath.roman.sk@gmail.com.
 // 

package knižnica;

/**
 * Rozhranie slúži na implementáciu metódy slúžiacej na zistenie farby
 * objektu a obsahuje definície konštánt farieb.
 * 
 * <P>(<a href="zoznam-zmien.html">Pozri zoznam zmien.</a>)
 * 
 *  @see GRobot.Farba
 */
public interface Farebnosť
{
	// …
	// Farby

	/**
	 * Farba, ktorá má všetky farebné zložky (aj zložku priehľadnosti) rovné
	 * nule (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int, int)
	 * Farba}{@code (}{@code num0}{@code , }{@code num0}{@code , }
	 * {@code num0}{@code , }{@code num0}{@code )}</small>).
	 * Technicky ide o neviditeľnú čiernu farbu. Táto inštancia je používaná
	 * v špeciálnych prípadoch.
	 */
	public final static GRobot.Farba žiadna = new GRobot.Farba(0, 0, 0, 0);

	/** <a class="alias"></a> Alias pre {@link #žiadna žiadna}. */
	public final static GRobot.Farba ziadna = žiadna;


	/**
	 * Biela farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num255}{@code , }{@code num255}{@code , }
	 * {@code num255}{@code )}</small>).
	 */
	public final static GRobot.Farba biela = new GRobot.Farba(255, 255, 255);

	/**
	 * Svetlošedá farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int,
	 * int) Farba}{@code (}{@code num176}{@code , }{@code num176}{@code , }
	 * {@code num176}{@code )}</small>).
	 */
	public final static GRobot.Farba svetlošedá = new GRobot.Farba(176, 176, 176);

	/** <a class="alias"></a> Alias pre {@link #svetlošedá svetlošedá}. */
	public final static GRobot.Farba svetloseda = svetlošedá;

	/**
	 * Šedá farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num144}{@code , }{@code num144}{@code , }
	 * {@code num144}{@code )}</small>).
	 */
	public final static GRobot.Farba šedá = new GRobot.Farba(144, 144, 144);

	/** <a class="alias"></a> Alias pre {@link #šedá šedá}. */
	public final static GRobot.Farba seda = šedá;

	/**
	 * Tmavošedá farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num96}{@code , }{@code num96}{@code , }
	 * {@code num96}{@code )}</small>).
	 */
	public final static GRobot.Farba tmavošedá = new GRobot.Farba(96, 96, 96);

	/** <a class="alias"></a> Alias pre {@link #tmavošedá tmavošedá}. */
	public final static GRobot.Farba tmavoseda = tmavošedá;

	/**
	 * {@link #svetlošedá Svetlošedá} farba
	 * (<small>{@link GRobot.Farba#GRobot.Farba(int, int,
	 * int) Farba}{@code (}{@code num176}{@code , }{@code num176}{@code , }
	 * {@code num176}{@code )}</small>).
	 */
	public final static GRobot.Farba svetlosivá = svetlošedá;

	/** <a class="alias"></a> Alias pre {@link #svetlošedá svetlošedá}. */
	public final static GRobot.Farba svetlosiva = svetlošedá;

	/**
	 * {@link #šedá Šedá} farba
	 * (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num144}{@code , }{@code num144}{@code , }
	 * {@code num144}{@code )}</small>).
	 */
	public final static GRobot.Farba sivá = šedá;

	/** <a class="alias"></a> Alias pre {@link #šedá šedá}. */
	public final static GRobot.Farba siva = šedá;

	/**
	 * {@link #tmavošedá Tmavošedá} farba
	 * (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num96}{@code , }{@code num96}{@code , }
	 * {@code num96}{@code )}</small>).
	 */
	public final static GRobot.Farba tmavosivá = tmavošedá;

	/** <a class="alias"></a> Alias pre {@link #tmavošedá tmavošedá}. */
	public final static GRobot.Farba tmavosiva = tmavošedá;

	/**
	 * Čierna farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num0}{@code , }{@code num0}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba čierna = new GRobot.Farba(0, 0, 0);

	/** <a class="alias"></a> Alias pre {@link #čierna čierna}. */
	public final static GRobot.Farba cierna = čierna;


	/**
	 * Svetločervená farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int,
	 * int) Farba}{@code (}{@code num224}{@code , }{@code num0}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba svetločervená = new GRobot.Farba(224, 0, 0);

	/** <a class="alias"></a> Alias pre {@link #svetločervená svetločervená}. */
	public final static GRobot.Farba svetlocervena = svetločervená;

	/**
	 * Červená farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num176}{@code , }{@code num0}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba červená = new GRobot.Farba(176, 0, 0);

	/** <a class="alias"></a> Alias pre {@link #červená červená}. */
	public final static GRobot.Farba cervena = červená;

	/**
	 * Tmavočervená farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int,
	 * int) Farba}{@code (}{@code num144}{@code , }{@code num0}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba tmavočervená = new GRobot.Farba(144, 0, 0);

	/** <a class="alias"></a> Alias pre {@link #tmavočervená tmavočervená}. */
	public final static GRobot.Farba tmavocervena = tmavočervená;


	/**
	 * Svetlozelená farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int,
	 * int) Farba}{@code (}{@code num0}{@code , }{@code num224}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba svetlozelená = new GRobot.Farba(0, 224, 0);

	/** <a class="alias"></a> Alias pre {@link #svetlozelená svetlozelená}. */
	public final static GRobot.Farba svetlozelena = svetlozelená;

	/**
	 * Zelená farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num0}{@code , }{@code num176}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba zelená = new GRobot.Farba(0, 176, 0);

	/** <a class="alias"></a> Alias pre {@link #zelená zelená}. */
	public final static GRobot.Farba zelena = zelená;

	/**
	 * Tmavozelená farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num0}{@code , }{@code num144}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba tmavozelená = new GRobot.Farba(0, 144, 0);

	/** <a class="alias"></a> Alias pre {@link #tmavozelená tmavozelená}. */
	public final static GRobot.Farba tmavozelena = tmavozelená;


	/**
	 * Svetlomodrá farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num0}{@code , }{@code num224}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba svetlomodrá = new GRobot.Farba(0, 0, 224);

	/** <a class="alias"></a> Alias pre {@link #svetlomodrá svetlomodrá}. */
	public final static GRobot.Farba svetlomodra = svetlomodrá;

	/**
	 * Modrá farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num0}{@code , }{@code num0}{@code , }
	 * {@code num176}{@code )}</small>).
	 */
	public final static GRobot.Farba modrá = new GRobot.Farba(0, 0, 176);

	/** <a class="alias"></a> Alias pre {@link #modrá modrá}. */
	public final static GRobot.Farba modra = modrá;

	/**
	 * Tmavomodrá farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num0}{@code , }{@code num0}{@code , }
	 * {@code num144}{@code )}</small>).
	 */
	public final static GRobot.Farba tmavomodrá = new GRobot.Farba(0, 0, 144);

	/** <a class="alias"></a> Alias pre {@link #tmavomodrá tmavomodrá}. */
	public final static GRobot.Farba tmavomodra = tmavomodrá;


	/**
	 * Svetlotyrkysová farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num0}{@code , }{@code num224}{@code , }
	 * {@code num224}{@code )}</small>).
	 */
	public final static GRobot.Farba svetlotyrkysová = new GRobot.Farba(0, 224, 224);

	/** <a class="alias"></a> Alias pre {@link #svetlotyrkysová svetlotyrkysová}. */
	public final static GRobot.Farba svetlotyrkysova = svetlotyrkysová;

	/**
	 * Tyrkysová farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num0}{@code , }{@code num176}{@code , }
	 * {@code num176}{@code )}</small>).
	 */
	public final static GRobot.Farba tyrkysová = new GRobot.Farba(0, 176, 176);

	/** <a class="alias"></a> Alias pre {@link #tyrkysová tyrkysová}. */
	public final static GRobot.Farba tyrkysova = tyrkysová;

	/**
	 * Tmavotyrkysová farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num0}{@code , }{@code num144}{@code , }
	 * {@code num144}{@code )}</small>).
	 */
	public final static GRobot.Farba tmavotyrkysová = new GRobot.Farba(0, 144, 144);

	/** <a class="alias"></a> Alias pre {@link #tmavotyrkysová tmavotyrkysová}. */
	public final static GRobot.Farba tmavotyrkysova = tmavotyrkysová;


	/**
	 * Svetlopurpurová farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num224}{@code , }{@code num0}{@code , }
	 * {@code num224}{@code )}</small>).
	 */
	public final static GRobot.Farba svetlopurpurová = new GRobot.Farba(224, 0, 224);

	/** <a class="alias"></a> Alias pre {@link #svetlopurpurová svetlopurpurová}. */
	public final static GRobot.Farba svetlopurpurova = svetlopurpurová;

	/**
	 * Purpurová farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num176}{@code , }{@code num0}{@code , }
	 * {@code num176}{@code )}</small>).
	 */
	public final static GRobot.Farba purpurová = new GRobot.Farba(176, 0, 176);

	/** <a class="alias"></a> Alias pre {@link #purpurová purpurová}. */
	public final static GRobot.Farba purpurova = purpurová;

	/**
	 * Tmavopurpurová farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num144}{@code , }{@code num0}{@code , }
	 * {@code num144}{@code )}</small>).
	 */
	public final static GRobot.Farba tmavopurpurová = new GRobot.Farba(144, 0, 144);

	/** <a class="alias"></a> Alias pre {@link #tmavopurpurová tmavopurpurová}. */
	public final static GRobot.Farba tmavopurpurova = tmavopurpurová;


	/**
	 * Svetložltá farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num240}{@code , }{@code num240}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba svetložltá = new GRobot.Farba(240, 240, 0);

	/** <a class="alias"></a> Alias pre {@link #svetložltá svetložltá}. */
	public final static GRobot.Farba svetlozlta = svetložltá;

	/**
	 * Žltá farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num224}{@code , }{@code num224}{@code , }
	 * {@code num0}{@code )}</small>).
	 * 
	 * <P><small>(<b>Poznámka:</b> Pozorné oko si môže všimnúť, že odtiene
	 * žltej sú definované z iných pomerov zložiek r, g, b, než odtiene
	 * iných základných farieb (červenej, zelenej, modrej…). Jednoduchým
	 * experimentom sa nám podarilo ukázať, že vnímanie „žltej“ je natoľko
	 * špecifické, že na to, aby bola vnímaná ako skutočne „žltá“, musí byť
	 * veľmi jasná. Preto pôvodná jasnožltá je teraz definovaná ako žltá
	 * a jej odtiene k nej majú veľmi blízko. Sami sa môžete presvedčiť, že
	 * na monitore pôsobia tmavšie odtiene „žltej“ ako žltozelená, olivová,
	 * lilavá, khaky… Ide čiastočne o psychochromatickú záležitosť a vplyv
	 * môže mať aj to, že vo farebnom priestore sRGB farba „žltá“ ako taká
	 * nejestvuje – je miešaná zo zložiek červenej a zelenej. „Technická“ žltá
	 * nie je taká žltá, aká je vnímaná ľuďmi.)</small>
	 */
	public final static GRobot.Farba žltá = new GRobot.Farba(224, 224, 0);

	/** <a class="alias"></a> Alias pre {@link #žltá žltá}. */
	public final static GRobot.Farba zlta = žltá;

	/**
	 * Tmavožltá farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num208}{@code , }{@code num208}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba tmavožltá = new GRobot.Farba(208, 208, 0);

	/** <a class="alias"></a> Alias pre {@link #tmavožltá tmavožltá}. */
	public final static GRobot.Farba tmavozlta = tmavožltá;


	/**
	 * Svetlohnedá farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num180}{@code , }{@code num96}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba svetlohnedá = new GRobot.Farba(180, 96, 0); // b46000

	/** <a class="alias"></a> Alias pre {@link #svetlohnedá svetlohnedá}. */
	public final static GRobot.Farba svetlohneda = svetlohnedá;

	/**
	 * Hnedá farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num160}{@code , }{@code num80}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba hnedá = new GRobot.Farba(160, 80, 0); // a05000

	/** <a class="alias"></a> Alias pre {@link #hnedá hnedá}. */
	public final static GRobot.Farba hneda = hnedá;

	/**
	 * Tmavohnedá farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num140}{@code , }{@code num64}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba tmavohnedá = new GRobot.Farba(140, 64, 0); // 8c4000

	/** <a class="alias"></a> Alias pre {@link #tmavohnedá tmavohnedá}. */
	public final static GRobot.Farba tmavohneda = tmavohnedá;


	/**
	 * Svetlooranžová farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num240}{@code , }{@code num180}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba svetlooranžová = new GRobot.Farba(240, 180, 0); // f0b400

	/** <a class="alias"></a> Alias pre {@link #svetlooranžová svetlooranžová}. */
	public final static GRobot.Farba svetlooranzova = svetlooranžová;

	/**
	 * Oranžová farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num220}{@code , }{@code num150}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba oranžová = new GRobot.Farba(220, 150, 0); // dc9600

	/** <a class="alias"></a> Alias pre {@link #oranžová oranžová}. */
	public final static GRobot.Farba oranzova = oranžová;

	/**
	 * Tmavooranžová farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int,
	 * int) Farba}{@code (}{@code num200}{@code , }{@code num120}{@code , }
	 * {@code num0}{@code )}</small>).
	 */
	public final static GRobot.Farba tmavooranžová = new GRobot.Farba(200, 120, 0); // c87800

	/** <a class="alias"></a> Alias pre {@link #tmavooranžová tmavooranžová}. */
	public final static GRobot.Farba tmavooranzova = tmavooranžová;


	/**
	 * Svetloružová farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num255}{@code , }{@code num217}{@code , }
	 * {@code num217}{@code )}</small>).
	 */
	public final static GRobot.Farba svetloružová = new GRobot.Farba(255, 217, 217); // ffd9d9

	/** <a class="alias"></a> Alias pre {@link #svetloružová svetloružová}. */
	public final static GRobot.Farba svetloruzova = svetloružová;

	/**
	 * Ružová farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num255}{@code , }{@code num179}{@code , }
	 * {@code num179}{@code )}</small>).
	 */
	public final static GRobot.Farba ružová = new GRobot.Farba(255, 179, 179); // ffb3b3

	/** <a class="alias"></a> Alias pre {@link #ružová ružová}. */
	public final static GRobot.Farba ruzova = ružová;

	/**
	 * Tmavoružová farba (<small>{@link GRobot.Farba#GRobot.Farba(int, int, int)
	 * Farba}{@code (}{@code num255}{@code , }{@code num140}{@code , }
	 * {@code num140}{@code )}</small>).
	 */
	public final static GRobot.Farba tmavoružová = new GRobot.Farba(255, 140, 140); // ff8c8c

	/** <a class="alias"></a> Alias pre {@link #tmavoružová tmavoružová}. */
	public final static GRobot.Farba tmavoruzova = tmavoružová;


	/**
	 * Zoznam (pole) všetkých preddefinovaných farieb.
	 */
	public final static GRobot.Farba preddefinovanéFarby[] = {biela,
		svetlošedá, šedá, tmavošedá, čierna, svetločervená, červená,
		tmavočervená, svetlozelená, zelená, tmavozelená, svetlomodrá,
		modrá, tmavomodrá, svetlotyrkysová, tyrkysová, tmavotyrkysová,
		svetlopurpurová, purpurová, tmavopurpurová, svetložltá, žltá,
		tmavožltá, svetlohnedá, hnedá, tmavohnedá, svetlooranžová,
		oranžová, tmavooranžová, svetloružová, ružová, tmavoružová};

	/** <a class="alias"></a> Alias pre {@link #preddefinovanéFarby preddefinovanéFarby}. */
	public final static GRobot.Farba preddefinovaneFarby[] =
		preddefinovanéFarby;


	/** Prototyp metódy na zistenie farby objektu. */
	public GRobot.Farba farba();

	// Odporúčané metódy na nastavenie novej farby objektu
	/* * Prototyp metódy na nastavenie farby objektu. * /
	public void farba(Color nováFarba);
	/* * Prototyp metódy na kopírovanie farby objektu. * /
	public void farba(Farebnosť podľaObjektu);
	/* * Prototyp metódy na nastavenie farby objektu. * /
	public GRobot.Farba farba(int r, int g, int b);
	/* * Prototyp metódy na nastavenie farby objektu. * /
	public GRobot.Farba farba(int r, int g, int b, int a);
	*/
}
