
 /////////////////////////////////////////////////////////////////////////////
 // This source code is part of the graphical framework called “Knižnica
 // grafického robota”. (The name is Slovak like the vast majority of own
 // identifiers used in this project.) The name translated to English means
 // “The Graphical Robot Library.”
 // 
 // Copyright © 2010 – 2016 by Roman Horváth
 // 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
 // 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU General Public License for more details.
 // 
 // You should have received a copy of the GNU General Public License
 // along with this program (look for the file named license.txt). If not,
 // see <http://www.gnu.org/licenses/> or
 // <https://www.gnu.org/licenses/gpl-3.0.txt>.
 // 
 // In case of any questions or requests, please, contact the author
 // Roman Horváth by e-mail: roman.horvath@truni.sk
 // or horvath.roman.sk@gmail.com.
 // 

package knižnica;

/**
 * Rozhranie slúži na implementáciu metód slúžiacich na zistenie polohy
 * objektu. Rozhranie vhodne dopĺňa jeho implementácia {@link GRobot.Bod Bod}.
 * 
 * <P>(<a href="zoznam-zmien.html">Pozri zoznam zmien.</a>)
 */
public interface Poloha
	// Ukázalo sa, že trieda Point2D.Double je na tieto účely nepoužiteľná.
	// Pri jej použití vznikali obrovské problémy dotýkajúce sa funkčnosti
	// prekrývania metódy kresliTvar() triedy GRobot. Možno išlo o nahlásiteľný
	// opraviteľný bug Javy, ale jednoduchšie pre nás bolo triedu nepoužiť,
	// navyše sme zhodnotili, že použitie rozhrania bude výhodnejšie.
{
	// public class Stred extends GRobot.Bod

	/**
	 * Preddefinovaná inštancia stredu súradnicovej sústavy. Ide o polohu
	 * so súradnicami 0, 0. Hodnotu tohto bodu nie je možné zmeniť!
	 */
	public final static GRobot.Bod stred = new GRobot.Bod()
	{
		// /**
		//  * Konštruktor, ktorý umožňuje korektnú inicializáciu tohto objektu.
		//  * (Bez tohto prekrytia, by inicializácia stredu zlyhala.)
		//  */
		// private Stred(double x, double y) { super.setLocation(x, y); }

		@Override public void setLocation(double x, double y)
		{ throw new GRobot.GRobotException("Polohu stredu nie je možné meniť!",
			"zeroPositionCannotBeChanged"); }

		@Override public void poloha(double x, double y)
		{ throw new GRobot.GRobotException("Polohu stredu nie je možné meniť!",
			"zeroPositionCannotBeChanged"); }

		@Override public void poloha(Poloha poloha)
		{ throw new GRobot.GRobotException("Polohu stredu nie je možné meniť!",
			"zeroPositionCannotBeChanged"); }
	};

	// …
	/** Prototyp metódy na zistenie súradnice objektu. */
	public double polohaX();
	/** Prototyp metódy na zistenie súradnice objektu. */
	public double polohaY();
	/** Prototyp metódy na zistenie súradnice objektu. */
	public double súradnicaX();
	/** Prototyp metódy na zistenie súradnice objektu. */
	public double suradnicaX();
	/** Prototyp metódy na zistenie súradnice objektu. */
	public double súradnicaY();
	/** Prototyp metódy na zistenie súradnice objektu. */
	public double suradnicaY();

	/** Prototyp metódy na zistenie obidvoch súradníc objektu. */
	public GRobot.Bod poloha();

	// Odporúčané protipóly metód na nastavenie súradníc alebo polohy objektu
	/* * Prototyp metódy na nastavenie súradnice objektu. * /
	public void polohaX(double novéX);
	/* * Prototyp metódy na nastavenie súradnice objektu. * /
	public void polohaY(double novéY);
	/* * Prototyp metódy na nastavenie súradnice objektu. * /
	public void súradnicaX(double novéX);
	/* * Prototyp metódy na nastavenie súradnice objektu. * /
	public void suradnicaX(double novéX);
	/* * Prototyp metódy na nastavenie súradnice objektu. * /
	public void súradnicaY(double novéY);
	/* * Prototyp metódy na nastavenie súradnice objektu. * /
	public void suradnicaY(double novéY);

	/* * Prototyp metódy na nastavenie obidvoch súradníc objektu. * /
	public void poloha(Poloha poloha);
	*/

	// skočNa[Myš]
}
